summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser.h
diff options
context:
space:
mode:
authorcsilv@chromium.org <csilv@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-18 01:29:42 +0000
committercsilv@chromium.org <csilv@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-18 01:29:42 +0000
commit4a42d27f346529b37f839b27b8b1dedd7e507002 (patch)
tree73c407a059acf1fc1252c64c201a5253135a28c2 /chrome/browser/browser.h
parent988506992537ed14bc02c00a2bae38088befcc0e (diff)
downloadchromium_src-4a42d27f346529b37f839b27b8b1dedd7e507002.zip
chromium_src-4a42d27f346529b37f839b27b8b1dedd7e507002.tar.gz
chromium_src-4a42d27f346529b37f839b27b8b1dedd7e507002.tar.bz2
Enable domui options for use in browser using the switch:
--enable-tabbed-options BUG=none TEST=see description Review URL: http://codereview.chromium.org/2820007 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@50191 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/browser.h')
-rw-r--r--chrome/browser/browser.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h
index 9939c2b..da30b6e 100644
--- a/chrome/browser/browser.h
+++ b/chrome/browser/browser.h
@@ -259,11 +259,12 @@ class Browser : public TabStripModelDelegate,
static void OpenBookmarkManagerWindow(Profile* profile);
#if defined(OS_MACOSX)
// Open a new window with history/downloads/help (needed on Mac when there are
// no windows).
static void OpenHistoryWindow(Profile* profile);
static void OpenDownloadsWindow(Profile* profile);
static void OpenHelpWindow(Profile* profile);
+ static void OpenOptionsWindow(Profile* profile);
#endif
// Opens a window with the extensions tab in it - needed by long-lived
@@ -521,6 +522,7 @@ class Browser : public TabStripModelDelegate,
void ShowDownloadsTab();
void ShowExtensionsTab();
void ShowBrokenPageTab(TabContents* contents);
+ void ShowOptionsTab();
void OpenClearBrowsingDataDialog();
void OpenOptionsDialog();
void OpenKeywordEditor();
@@ -259,11 +259,12 @@ class Browser : public TabStripModelDelegate,
static void OpenBookmarkManagerWindow(Profile* profile);
#if defined(OS_MACOSX)
- // Open a new window with history/downloads/help (needed on Mac when there are
- // no windows).
+ // Open a new window with history/downloads/help/options (needed on Mac when
+ // there are no windows).
static void OpenHistoryWindow(Profile* profile);
static void OpenDownloadsWindow(Profile* profile);